summaryrefslogtreecommitdiff
path: root/arch/sandbox/include/asm/gpio.h
diff options
context:
space:
mode:
Diffstat (limited to 'arch/sandbox/include/asm/gpio.h')
-rw-r--r--arch/sandbox/include/asm/gpio.h36
1 files changed, 30 insertions, 6 deletions
diff --git a/arch/sandbox/include/asm/gpio.h b/arch/sandbox/include/asm/gpio.h
index 8317db1..73b42f0 100644
--- a/arch/sandbox/include/asm/gpio.h
+++ b/arch/sandbox/include/asm/gpio.h
@@ -26,7 +26,8 @@
/**
* Return the simulated value of a GPIO (used only in sandbox test code)
*
- * @param gp GPIO number
+ * @param dev device to use
+ * @param offset GPIO offset within bank
* @return -1 on error, 0 if GPIO is low, >0 if high
*/
int sandbox_gpio_get_value(struct udevice *dev, unsigned int offset);
@@ -34,25 +35,48 @@ int sandbox_gpio_get_value(struct udevice *dev, unsigned int offset);
/**
* Set the simulated value of a GPIO (used only in sandbox test code)
*
* @param gp GPIO number
* @param value value to set (0 for low, non-zero for high)
* @return -1 on error, 0 if ok
*/
int sandbox_gpio_set_value(struct udevice *dev, unsigned int offset, int value);
/**
- * Return the simulated direction of a GPIO (used only in sandbox test code)
+ * Set or reset the simulated open drain mode of a GPIO (used only in sandbox
+ * test code)
+ *
+ * @param gp GPIO number
+ * @param value value to set (0 for enabled open drain mode, non-zero for
+ * disabled)
+ * @return -1 on error, 0 if ok
+ */
+int sandbox_gpio_set_open_drain(struct udevice *dev, unsigned offset, int value);
+
+/**
+ * Return the state of the simulated open drain mode of a GPIO (used only in
+ * sandbox test code)
*
* @param gp GPIO number
* @return -1 on error, 0 if GPIO is input, >0 if output
*/
+int sandbox_gpio_get_open_drain(struct udevice *dev, unsigned offset);
+
+/**
+ * Return the simulated direction of a GPIO (used only in sandbox test code)
+ *
+ * @param dev device to use
+ * @param offset GPIO offset within bank
+ * @return -1 on error, 0 if GPIO is input, >0 if output
+ */
int sandbox_gpio_get_direction(struct udevice *dev, unsigned int offset);
/**
* Set the simulated direction of a GPIO (used only in sandbox test code)
*
- * @param gp GPIO number
- * @param output 0 to set as input, 1 to set as output
+ * @param dev device to use
+ * @param offset GPIO offset within bank
+ * @param output 0 to set as input, 1 to set as output
* @return -1 on error, 0 if ok
*/
int sandbox_gpio_set_direction(struct udevice *dev, unsigned int offset,
@@ -34,25 +35,48 @@ int sandbox_gpio_get_value(struct udevice *dev, unsigned int offset);
* Set the simulated value of a GPIO (used only in sandbox test code)
*
- * @param gp GPIO number
- * @param value value to set (0 for low, non-zero for high)
+ * @param dev device to use
+ * @param offset GPIO offset within bank
+ * @param value value to set (0 for low, non-zero for high)
* @return -1 on error, 0 if ok
*/